@@ -17,7 +17,7 @@ from reportlab.lib.styles import getSampleStyleSheet, ParagraphStyle
 from reportlab.platypus import SimpleDocTemplate, Paragraph, Spacer, Image,  Table, TableStyle, PageBreak, Flowable
 
 
-def LATTE_DV(tic, indir, syspath, transit_list, sectors_all, target_ra, target_dec, tessmag, teff, srad, bls_stats1, bls_stats2, tpf_corrupt, astroquery_corrupt, FFI, bls = False, model = False, mpi = False, test = 'no'):
+def LATTE_DV(tic, indir, syspath, transit_list, sectors_all, target_ra, target_dec, tessmag, teff, srad, mstar, vmag, logg, plx, c_id, bls_stats1, bls_stats2, tpf_corrupt, astroquery_corrupt, FFI, bls = False, model = False, mpi = False, test = 'no'):
 
 	'''
 	funtion that makes compiles all of the information and figures into a comprehensive pdf summary document.
@@ -113,7 +113,7 @@ def LATTE_DV(tic, indir, syspath, transit_list, sectors_all, target_ra, target_d
 	#------------------------------------------------------------------
 	
 	# plot the full light curve, with marked sectors and marked transit - binned and unbinned
-
+	
 	full_LC_name = "{}/{}/{}_fullLC_md.png".format(indir,tic,tic)
 	
 	background_flux_name = '{}/{}/{}_background.png'.format(indir, tic, tic)
@@ -142,6 +142,10 @@ def LATTE_DV(tic, indir, syspath, transit_list, sectors_all, target_ra, target_d
 	
 	apertures_name = '{}/{}/{}_apertures_0.png'.format(indir, tic, tic)
 	
+	periodogram_name = '{}/{}/{}_periodogram.png'.format(indir, tic, tic)
+
+	eep_name = '{}/{}/{}_eep.png'.format(indir, tic, tic)
+
 	# ----- LOGOS ------
 	# if this is a unittest run, find the files for the logos stored in the test folder
 	if test != 'no':
@@ -162,7 +166,7 @@ def LATTE_DV(tic, indir, syspath, transit_list, sectors_all, target_ra, target_d
 
 	doc = SimpleDocTemplate("{}/{}/DV_report_{}.pdf".format(indir,tic,tic) ,pagesize=A4,
 						   rightMargin=72,leftMargin=72,
-						   topMargin=40,bottomMargin=20)
+						   topMargin=30,bottomMargin=20)
 
 	width, height = A4 # this is useful when defining where to plot something on the page
 	
@@ -182,7 +186,7 @@ def LATTE_DV(tic, indir, syspath, transit_list, sectors_all, target_ra, target_d
 	
 	Story.append(Paragraph(ptext, styles["centre"]))
 	Story.append(Paragraph(subtext, styles["centre"]))
-	Story.append(Spacer(1, 30))
+	Story.append(Spacer(1, 25))
 	
 	# ----- ADD THE LOGOS -------
 	PHT_logo =   Image(PHT_logo_name)
@@ -220,13 +224,14 @@ def LATTE_DV(tic, indir, syspath, transit_list, sectors_all, target_ra, target_d
 	# Full Image with momentum dumps
 	# --------------------------------------------
 	im = Image(full_LC_name)
-	im._restrictSize(width*0.8, width*0.8)
+	im._restrictSize(width*0.76, width*0.76)
 	Story.append(im)
 	
 	fig_count += 1
 
-	full_image_text = "Fig {}. Full lightcurve for target TIC {}. The solid red lines at the bottom of the figure indicated the \
-	times of the momentum dumps and the dashed black line(s) show the time(s) of the marked transit event(s).".format(fig_count,tic)
+	full_image_text = "Fig {}. Full lightcurve for target TIC {}. The solid blue lines at the bottom of the figure indicated the \
+	times of the reaction wheel momentum dumps and the dashed black line(s) show the time(s) of the marked transit event(s). Momentum dumps \
+	occur around every 2 to 2.5 days and typically last around half an hour.".format(fig_count,tic)
 	
 	ptext = '<font size=8>%s</font>' % full_image_text
 	Story.append(Paragraph(ptext, styles["Normal"]))
@@ -235,32 +240,59 @@ def LATTE_DV(tic, indir, syspath, transit_list, sectors_all, target_ra, target_d
 	# ------ stellar parameters table ------
 	# --------------------------------------
 	try:
-		srad = float(srad)
+		srad = np.round(srad, 2)
 	except:
-		srad = -999
+		srad = '--'
 	
 	try:
-		teff = float(teff)
+		teff = np.round(teff, 0)
 	except:
-		teff = -999
-			
+		teff = '--'
+
+	try:
+		mstar = np.round(mstar, 2)
+	except:
+		mstar = '--'
+
+	try:
+		plx = np.round(plx, 2)
+	except:
+		plx = '--'
+
+	try:
+		vmag = np.round(vmag, 2)
+	except:
+		vmag = '--'
+
+
+	nominal_mission_sectors = list(np.array(sectors_all)[np.array(sectors_all) < 27])
+	extended_mission_sectors = list(np.array(sectors_all)[np.array(sectors_all) > 26])
+
+
+	# mstar, vmag, logg, plx, c_id
+
 	data_stellar= [['Parameter',  "Value", "Unit"],
 				   ['TIC ID',	 tic, ],
-				   ['RA',		 ra, "degrees"],
-				   ['Dec',		dec, "degrees"],
-				   ['Radius',	 "{:.4f}".format(srad), "Solar Radii"],
-				   ['Tess Mag',   "{:.4f}".format(tessmag), "Mag"],
-				   ['Teff',	   "{:.0f}".format(teff), "Kelvin"],
-				   ['Sectors',	  "{} *".format(str(sectors_all)[1:-1]), ],
+				   ['Other name',	 c_id, ],
+				   ['RA/Dec',		"{}  {}".format(ra, dec), "degrees"],
+				   ['Radius',	 "{}".format(srad), "Solar Radii"],
+				   ['Mass',	     "{}".format(mstar), "Solar Mass"],
+				   ['Teff',	     "{}".format(teff), "Kelvin"],
+				   ['Parallax',	     "{}".format(plx), " "],
+				   ['T mag',     "{}".format(tessmag), "Mag"],
+				   ['V mag',     "{}".format(vmag), "Mag"],
+				   ['Sectors (nominal)',	  "{} *".format(str(nominal_mission_sectors)[1:-1]),],
+				   ['Sectors (extended)',	  "{} *".format(str(extended_mission_sectors)[1:-1]),],
 				   ['TCE',	  TCE, ],
 				   ['TOI',	  "{}".format(str(TOI)), ],
 				   ]
 	
+	
 	table_stellar=Table(data_stellar)
-	table_stellar=Table(data_stellar,colWidths=width * 0.2, style=[
+	table_stellar=Table(data_stellar,colWidths=width * 0.24, style=[
 						('LINEABOVE',(0,1),(-1,1),1,colors.black),
-						('LINEABOVE',(0,10),(-1,10),1,colors.black),
-						('FONTSIZE', (0,0),(-1,9), 8),
+						('LINEABOVE',(0,11),(-1,11),1,colors.black),
+						('FONTSIZE', (0,0),(-1,13), 8),
 						])
 
 	data_len = len(data_stellar)
@@ -283,9 +315,9 @@ def LATTE_DV(tic, indir, syspath, transit_list, sectors_all, target_ra, target_d
 	# ------
 	
 	Story.append(Spacer(1, 20))
-	ptext = '<font size=9>Target Properties</font>'
-	Story.append(Paragraph(ptext, styles["Normal"]))
-	Story.append(Spacer(1, 12))
+	#ptext = '<font size=9>Target Properties</font>'
+	#Story.append(Paragraph(ptext, styles["Normal"]))
+	#Story.append(Spacer(1, 12))
 	
 	Story.append(table_stellar)
 	Story.append(Spacer(1, 15))
@@ -298,18 +330,16 @@ def LATTE_DV(tic, indir, syspath, transit_list, sectors_all, target_ra, target_d
 
 	if TCE == 'Yes **':
 		Stellartable_text = "Table {}. Stellar properties of {}. \
-			* List of the sectors in which the target will be has been \
+			* List of the sectors in which the target will be, or has been, \
 			observed. ** Click {} for the TCE report.".format(table_count, exofop_link, TCE_link)
 
 
 	else:
 		Stellartable_text = "Table {}. Stellar properties of the {}. \
-			* List of the sectors in which the target will be has been \
+			* List of the sectors in which the target will be, or has been, \
 			observed.".format(table_count,exofop_link)
 
-		
-
-
+	
 	ptext = '<font size=8>%s</font>' % Stellartable_text
 	Story.append(Paragraph(ptext, styles["Normal"]))
 
@@ -317,7 +347,10 @@ def LATTE_DV(tic, indir, syspath, transit_list, sectors_all, target_ra, target_d
 	# --------------------------------------------
 	# Background
 	# --------------------------------------------
-	Story.append(PageBreak()) # always start a new page for this analysis
+	if FFI == False:
+		Story.append(PageBreak()) # always start a new page for this analysis
+		Story.append(Spacer(1, 20))
+
 	im2 = Image(background_flux_name)
 	
 	if len(transit_list) == 1:
@@ -342,7 +375,7 @@ def LATTE_DV(tic, indir, syspath, transit_list, sectors_all, target_ra, target_d
 	# --------------------------------------------
 	
 	if FFI == False:
-		Story.append(Spacer(1, 10))
+
 		im3 = Image(centroid_positions_name)
 
 		if len(transit_list) == 1:
@@ -363,7 +396,7 @@ def LATTE_DV(tic, indir, syspath, transit_list, sectors_all, target_ra, target_d
 
 		Story.append(Paragraph(ptext, styles["Normal"]))
 		
-		Story.append(Spacer(1, 13))
+		Story.append(Spacer(1, 16))
 
 		#Story.append(PageBreak()) # always start a new page for this analysis
 
@@ -373,6 +406,10 @@ def LATTE_DV(tic, indir, syspath, transit_list, sectors_all, target_ra, target_d
 		# --------------------------------------------
 		# Flux Aperture
 		# --------------------------------------------
+		if FFI == False:
+			Story.append(PageBreak()) # always start a new page for this analysis
+			Story.append(Spacer(1, 10))
+
 		im4 = Image(flux_aperture_name)
 	
 		if len(transit_list) == 1:
@@ -382,8 +419,8 @@ def LATTE_DV(tic, indir, syspath, transit_list, sectors_all, target_ra, target_d
 		Story.append(im4)
 		
 		fig_count += 1
-		Story.append(Spacer(1, 10))
-		flux_aperture_text = "Fig {}. The lighcurve around the time of each transit-like event extracted with the SPOC pipeline \
+		Story.append(Spacer(1, 16))
+		flux_aperture_text = "Fig {}. The lightcurve around the time of each transit-like event extracted with the SPOC pipeline \
 			defined aperture (binned:blue, unbinned:grey) and the with an aperture that is 40 per cent smaller (red). The flux is extracted \
 			from the target pixel files (TPFs) and has not been detrended or \
 			corrected for systematics. The vertical orange line indicates the time of the transit-like event.".format(fig_count)
@@ -394,6 +431,9 @@ def LATTE_DV(tic, indir, syspath, transit_list, sectors_all, target_ra, target_d
 		# --------------------------------------------
 		# Apertures Sizes
 		# --------------------------------------------
+		
+		Story.append(Spacer(1, 25))
+
 		im45 = Image(apertures_name)
 		
 		im45._restrictSize(width*0.4, width*0.4)
@@ -402,7 +442,7 @@ def LATTE_DV(tic, indir, syspath, transit_list, sectors_all, target_ra, target_d
 		
 		fig_count += 1
 
-		Story.append(Spacer(1, 10))
+		Story.append(Spacer(1, 16))
 
 		if FFI == False:
 			aperture_text = "Fig {}. The apertures used to extract the lightcurves. The blue aperture on the right shows the \
@@ -420,17 +460,17 @@ def LATTE_DV(tic, indir, syspath, transit_list, sectors_all, target_ra, target_d
 		# In and Out of Transit Comparison
 		# --------------------------------------------
 		
-		Story.append(Spacer(1, 12))
+		Story.append(Spacer(1, 25))
+
 		im5 = Image(in_out_name)
 	
-	
-		im5._restrictSize(width*0.9, width*0.9)
+		im5._restrictSize(width*0.85, width*0.85)
 	
 		Story.append(im5)
 	
 		fig_count += 1
-		Story.append(Spacer(1, 10))
-		flux_aperture_text = "Fig {}. Diffrence images for target TIC {} for each transit like event. \
+		Story.append(Spacer(1, 16))
+		flux_aperture_text = "Fig {}. Difference images for target TIC {} for each transit like event. \
 		Left: mean in-transit flux(left). Middle: mean out-of-transit flux. Right: difference between the mean out-of-transit and mean in-transit flux. \
 		Ensure that the change in brightness occurs on target.".format(fig_count, tic)
 		
@@ -444,7 +484,9 @@ def LATTE_DV(tic, indir, syspath, transit_list, sectors_all, target_ra, target_d
 		# can only put this in the report if astroquery is working. 
 		if astroquery_corrupt == False:
 
-			Story.append(Spacer(1, 12))
+			if FFI == False:
+				Story.append(PageBreak()) # always start a new page for this analysis
+				Story.append(Spacer(1, 20))
 		
 			im6 = Image(tess_stars_name)
 			
@@ -457,13 +499,14 @@ def LATTE_DV(tic, indir, syspath, transit_list, sectors_all, target_ra, target_d
 			Story.append(im6)
 		
 			fig_count += 1
-			tess_stars_text = "Fig {}. Left: The locations of nearby GAIA DR2 stars with mag < 15 (orange circle) within the Tess \
+			tess_stars_text = "Fig {}. The locations of nearby GAIA DR2 stars with a magnitude difference less than 5 (orange circle) within the Tess \
 			Cut Out around TIC {} (red star). Only shown for one sector. Right: SDSS image of the surrounding field.".format(fig_count, tic)
 			
 			ptext = '<font size=8>%s</font>' % tess_stars_text
 			Story.append(Paragraph(ptext, styles["Normal"]))
 		
-	
+			Story.append(Spacer(1, 30))
+			
 	# --------------------------------------------
 	# nearest neighbours
 	# --------------------------------------------
@@ -488,7 +531,9 @@ def LATTE_DV(tic, indir, syspath, transit_list, sectors_all, target_ra, target_d
 		# --------------------------------------------
 		# pixel_LCs_name
 		# --------------------------------------------
-		Story.append(Spacer(1, 10))
+		Story.append(PageBreak()) # always start a new page for this analysis
+		Story.append(Spacer(1, 20))
+		
 		im8 = Image(pixel_LCs_name)
 		
 	
@@ -504,7 +549,6 @@ def LATTE_DV(tic, indir, syspath, transit_list, sectors_all, target_ra, target_d
 	
 	# ------ Phase Folded LC ------
 
-
 	if len(transit_list) > 1:
 
 		# --------------------------------------------
@@ -525,70 +569,123 @@ def LATTE_DV(tic, indir, syspath, transit_list, sectors_all, target_ra, target_d
 		
 
 	# ------ BLS -------
-	Story.append(PageBreak()) # always start a new page for this analysis
-	# ------
-
+	
 	if bls == True:
 		
-		Story.append(Spacer(1, 12))
-		blsim1 = Image(bls1)
-		blsim2 = Image(bls2)
-
-		blsim1._restrictSize(width*0.6, width*0.6)
-		blsim2._restrictSize(width*0.6, width*0.6)
-
-		bls_table = (Table([[blsim1, blsim2]],
-						colWidths=[width * 0.45], rowHeights=[width * 0.6]))
+		if len(bls_stats2) > 1: # if the first AND second BLS worked
+			Story.append(PageBreak()) # always start a new page for this analysis
 	
-		bls_table.setStyle(TableStyle([('ALIGN', (0, 0), (-1, -1), 'CENTRE'),('VALIGN', (0, 0), (-1,-1), 'MIDDLE')]))
-		
-		Story.append(bls_table)
-
-		fig_count += 1
-
-		if FFI == False:
-
-			bls1_text = "Fig {}. Box Least Square fitting (BLS) for whole lightcurve binned to 10 minutes. Top left panel: log liklihood periodogram. \
-							The solid red line indicates the peak period and the dashed orange lines show the integer \
-							harmonics of this period. Middle left panel: Full light curve, unbinned (orange) and binned to 10 minutes (black). \
-							The peak period is highlighted by the solid red lines. Bottom left Panel: Phase folded light curve where the found transit-event is fit \
-							with a simple box (red line). The pannels on the right show the same diagnostics, however the diagnostic \
-							was run with the highest detected signal-to-noise transits, from the initial BLS search, removed. ".format(fig_count)
-		
-		else:
-			bls1_text = "Fig {}. Box Least Square fitting (BLS) for whole lightcurve. Top left panel: log liklihood periodogram. \
-							The solid blue line indicates the peak period and the dashed red lines show the integer \
-							harmonics of this period. Middle left panel: Full light curve, unbinned LC (orange) . \
-							The peak period is highlighted by the solid blue lines. Bottom left Panel: Phase folded light curve where the found transit-event is fit \
-							with a simple box (blue line). The pannels on the right show the same diagnostics, however the diagnostic \
-							was run with the highest detected signal-to-noise transits, from the initial BLS search, removed. ".format(fig_count)
-		
-
-		ptext = '<font size=8>%s</font>' % bls1_text
-		Story.append(Paragraph(ptext, styles["Normal"]))
-		
-
-
-		# --------------------
-		# ---- BLS TABLE -----
-
-		data_bls= [['Parameter',				  "bls1",														"bls2"],
-					   ['period',			    "{:.3f}".format(bls_stats1[0]),	         						 "{:.3f}".format(bls_stats2[0])],
-					   ['t0',			        "{:.2f}".format(bls_stats1[1]),	         						 "{:.2f}".format(bls_stats2[1])],
-					   ['depth',			    "{:.5f} ± {:.5f}".format(bls_stats1[2][0],bls_stats1[2][1]),	 "{:.5f} ± {:.5f}".format(bls_stats2[2][0],bls_stats2[2][1]) ],
-					   ['depth phased',			"{:.5f} ± {:.5f}".format(bls_stats1[3][0],bls_stats1[3][1]),	 "{:.5f} ± {:.5f}".format(bls_stats2[3][0],bls_stats2[3][1]) ],
-					   ['depth half',			"{:.5f} ± {:.5f}".format(bls_stats1[4][0],bls_stats1[4][1]),	 "{:.5f} ± {:.5f}".format(bls_stats2[4][0],bls_stats2[4][1]) ],
-					   ['depth odd',			"{:.5f} ± {:.5f}".format(bls_stats1[5][0],bls_stats1[5][1]),	 "{:.5f} ± {:.5f}".format(bls_stats2[5][0],bls_stats2[5][1]) ],
-					   ['depth even',			"{:.5f} ± {:.5f}".format(bls_stats1[6][0],bls_stats1[6][1]),	 "{:.5f} ± {:.5f}".format(bls_stats2[6][0],bls_stats2[6][1]) ],
-					   ]
-		
-		table_bls=Table(data_bls)
-		table_bls=Table(data_bls,colWidths=width * 0.2, style=[
-							('LINEABOVE',(0,1),(-1,1),1,colors.black),
-							('LINEABOVE',(0,8),(-1,8),1,colors.black),
-							('FONTSIZE', (0,0),(-1,7), 8),
-							])
+			Story.append(Spacer(1, 12))
+			blsim1 = Image(bls1)
+			blsim2 = Image(bls2)
 	
+			blsim1._restrictSize(width*0.6, width*0.6)
+			blsim2._restrictSize(width*0.6, width*0.6)
+	
+			bls_table = (Table([[blsim1, blsim2]],
+							colWidths=[width * 0.45], rowHeights=[width * 0.6]))
+		
+			bls_table.setStyle(TableStyle([('ALIGN', (0, 0), (-1, -1), 'CENTRE'),('VALIGN', (0, 0), (-1,-1), 'MIDDLE')]))
+			
+			Story.append(bls_table)
+	
+			fig_count += 1
+	
+			if FFI == False:
+	
+				bls1_text = "Fig {}. Box Least Square fitting (BLS) for whole lightcurve binned to 10 minutes. Top left panel: log liklihood periodogram. \
+								The solid red line indicates the peak period and the dashed orange lines show the integer \
+								harmonics of this period. Middle left panel: Full light curve, unbinned (orange) and binned to 10 minutes (black). \
+								The peak period is highlighted by the solid red lines. Bottom left Panel: Phase folded light curve where the found transit-event is fit \
+								with a simple box (red line). The pannels on the right show the same diagnostics, however the diagnostic \
+								was run with the highest detected signal-to-noise transits, from the initial BLS search, removed. ".format(fig_count)
+			
+			else:
+				bls1_text = "Fig {}. Box Least Square fitting (BLS) for whole lightcurve. Top left panel: log liklihood periodogram. \
+								The solid blue line indicates the peak period and the dashed red lines show the integer \
+								harmonics of this period. Middle left panel: Full light curve, unbinned LC (orange) . \
+								The peak period is highlighted by the solid blue lines. Bottom left Panel: Phase folded light curve where the found transit-event is fit \
+								with a simple box (blue line). The pannels on the right show the same diagnostics, however the diagnostic \
+								was run with the highest detected signal-to-noise transits, from the initial BLS search, removed. ".format(fig_count)
+			
+	
+			ptext = '<font size=8>%s</font>' % bls1_text
+			Story.append(Paragraph(ptext, styles["Normal"]))
+			
+	
+	
+			# --------------------
+			# ---- BLS TABLE -----
+	
+			data_bls= [['Parameter',				  "bls1",														"bls2"],
+						   ['period',			    "{:.3f}".format(bls_stats1[0]),	         						 "{:.3f}".format(bls_stats2[0])],
+						   ['t0',			        "{:.2f}".format(bls_stats1[1]),	         						 "{:.2f}".format(bls_stats2[1])],
+						   ['depth',			    "{:.5f} ± {:.5f}".format(bls_stats1[2][0],bls_stats1[2][1]),	 "{:.5f} ± {:.5f}".format(bls_stats2[2][0],bls_stats2[2][1]) ],
+						   ['depth phased',			"{:.5f} ± {:.5f}".format(bls_stats1[3][0],bls_stats1[3][1]),	 "{:.5f} ± {:.5f}".format(bls_stats2[3][0],bls_stats2[3][1]) ],
+						   ['depth half',			"{:.5f} ± {:.5f}".format(bls_stats1[4][0],bls_stats1[4][1]),	 "{:.5f} ± {:.5f}".format(bls_stats2[4][0],bls_stats2[4][1]) ],
+						   ['depth odd',			"{:.5f} ± {:.5f}".format(bls_stats1[5][0],bls_stats1[5][1]),	 "{:.5f} ± {:.5f}".format(bls_stats2[5][0],bls_stats2[5][1]) ],
+						   ['depth even',			"{:.5f} ± {:.5f}".format(bls_stats1[6][0],bls_stats1[6][1]),	 "{:.5f} ± {:.5f}".format(bls_stats2[6][0],bls_stats2[6][1]) ],
+						   ]
+			
+			table_bls=Table(data_bls)
+			table_bls=Table(data_bls,colWidths=width * 0.2, style=[
+								('LINEABOVE',(0,1),(-1,1),1,colors.black),
+								('LINEABOVE',(0,8),(-1,8),1,colors.black),
+								('FONTSIZE', (0,0),(-1,7), 8),
+								])
+		
+		else: # if the first BLS returned a period that was very short such that the second one didn't work.
+			Story.append(PageBreak()) # always start a new page for this analysis
+	
+			Story.append(Spacer(1, 12))
+			blsim1 = Image(bls1)
+			#blsim2 = Image(bls2)
+	
+			blsim1._restrictSize(width*0.6, width*0.6)
+
+			Story.append(blsim1)
+	
+			fig_count += 1
+	
+			if FFI == False:
+	
+				bls1_text = "Fig {}. Box Least Square fitting (BLS) for whole lightcurve binned to 10 minutes. Top panel: log liklihood periodogram. \
+								The solid red line indicates the peak period and the dashed orange lines show the integer \
+								harmonics of this period. Middle panel: Full light curve, unbinned (orange) and binned to 10 minutes (black). \
+								The peak period is highlighted by the solid red lines. Bottom panel: Phase folded light curve where the found transit-event is fit \
+								with a simple box (red line). ".format(fig_count)
+			
+			else:
+				bls1_text = "Fig {}. Box Least Square fitting (BLS) for whole lightcurve. Top panel: log liklihood periodogram. \
+								The solid blue line indicates the peak period and the dashed red lines show the integer \
+								harmonics of this period. Middle panel: Full light curve, unbinned LC (orange) . \
+								The peak period is highlighted by the solid blue lines. Bottom  panel: Phase folded light curve where the found transit-event is fit \
+								with a simple box (blue line). ".format(fig_count)
+			
+	
+			ptext = '<font size=8>%s</font>' % bls1_text
+			Story.append(Paragraph(ptext, styles["Normal"]))
+			
+	
+			# --------------------
+			# ---- BLS TABLE -----
+	
+			data_bls= [['Parameter',				  "bls1"													 ],
+						   ['period',			    "{:.3f}".format(bls_stats1[0])	         					 ],
+						   ['t0',			        "{:.2f}".format(bls_stats1[1])	         					 ],
+						   ['depth',			    "{:.5f} ± {:.5f}".format(bls_stats1[2][0],bls_stats1[2][1])	 ],
+						   ['depth phased',			"{:.5f} ± {:.5f}".format(bls_stats1[3][0],bls_stats1[3][1])	 ],
+						   ['depth half',			"{:.5f} ± {:.5f}".format(bls_stats1[4][0],bls_stats1[4][1])	 ],
+						   ['depth odd',			"{:.5f} ± {:.5f}".format(bls_stats1[5][0],bls_stats1[5][1])	 ],
+						   ['depth even',			"{:.5f} ± {:.5f}".format(bls_stats1[6][0],bls_stats1[6][1])	 ],
+						   ]
+			
+			table_bls=Table(data_bls)
+			table_bls=Table(data_bls,colWidths=width * 0.2, style=[
+								('LINEABOVE',(0,1),(-1,1),1,colors.black),
+								('LINEABOVE',(0,8),(-1,8),1,colors.black),
+								('FONTSIZE', (0,0),(-1,7), 8),
+								])
 
 		# ------ ADD A LINE TO SEPERATE SECTIONS -------
 		
@@ -618,13 +715,56 @@ def LATTE_DV(tic, indir, syspath, transit_list, sectors_all, target_ra, target_d
 		Story.append(Spacer(1, 15))
 
 		table_count += 1
-		Stellartable_text = "Table {}. Summary of the two BLS fits. Fit one is run with the whole lightcurve and fit two is run with the highest detected signal-to-noise transits removed.".format(table_count)
+		Stellartable_text = "Table {}. Summary of the BLS fit.".format(table_count)
 		ptext = '<font size=8>%s</font>' % Stellartable_text
 		Story.append(Paragraph(ptext, styles["Normal"]))
 
 		Story.append(PageBreak())
 		# -----------
 
+	# analysis of the star i.e. periodogram and the evolutionary tracks
+	
+	#periodogram_name
+
+	# --------------------------------------------
+	# Peiodogram
+	# --------------------------------------------
+	Story.append(Spacer(1, 20))
+
+	imp = Image(periodogram_name)
+
+	imp._restrictSize(width*0.5, width*0.5)
+
+	Story.append(imp)
+	
+	fig_count += 1
+	Story.append(Spacer(1, 10))
+	periodogram_text = "Fig {}. Lomb scargle periodogram of the TESS lightcurve (black line) and a boxcar-smoothed periogram (pink line) computerd with a window length of 20 micro Hz.".format(fig_count)
+	
+	ptext = '<font size=8>%s</font>' % periodogram_text
+	Story.append(Paragraph(ptext, styles["Normal"]))
+	
+
+	# --------------------------------------------
+	# eep
+	# --------------------------------------------
+	Story.append(Spacer(1, 20))
+
+	imp = Image(eep_name)
+
+	imp._restrictSize(width*0.5, width*0.5)
+
+	Story.append(imp)
+	
+	fig_count += 1
+	Story.append(Spacer(1, 10))
+	periodogram_text = "Fig {}. The equivalent evolutionary phase (eep) tracks for main sequence evolution (solid lines) and post \
+	main-sequence evolution (dashed lines) for masses ranging from 0.3 to 1.6 solar masses (from right to left). \
+	The 1 Solar Mass track is shown in maroon. The blue points show the TOIs and the magenta point TIC {}.".format(fig_count, tic)
+	
+	ptext = '<font size=8>%s</font>' % periodogram_text
+	Story.append(Paragraph(ptext, styles["Normal"]))
+	
 
 	if model == True:
 
@@ -771,7 +911,8 @@ class MCLine(Flowable):
 		"""
 		self.canv.setStrokeColor(grey)
 		self.canv.line(0, self.height, self.width, self.height)
-	  
+
+
 class MCLine_color(Flowable):
 	"""
 	Line flowable --- draws a line in a flowable in COLOUR
